@@ -8,10 +8,10 @@ from ._rebase import (
     rebase_all_coords,
     rebase_on_grid,
     rebase_on_time,
+    rezero_time,
     squash_placeholders,
     standardize_grid,
     standardize_grid_and_time,
-    standardize_time,
 )
 
 logger = logging.getLogger(__name__)
@@ -25,7 +25,7 @@ __all__ = [
     'rebase_all_coords',
     'standardize_grid_and_time',
     'standardize_grid',
-    'standardize_time',
+    'rezero_time',
     'squash_placeholders',
     'imas_mocked',
 ]
