@@ -1,4 +1,5 @@
-from typing import List, Sequence
+import logging
+from typing import Sequence
 
 import xarray as xr
 
@@ -9,12 +10,16 @@ from ..utils import groupby
 from ._handle import ImasHandle
 from ._rebase import rebase_all_coords, squash_placeholders
 
+logger = logging.getLogger(__name__)
+
+info = logger.info
+
 
 @add_to_op_queue('Merging to', '{target}')
 def merge_data(
     handles: Sequence[ImasHandle],
     target: ImasHandle,
-    variables: List[IDSVariableModel],
+    variables: list[IDSVariableModel],
     callback=None,
 ):
     """merge_data merges the data from the handles to the target, only merges
@@ -57,6 +62,12 @@ def merge_data(
 
         # Get all data, and rebase it
         target_ids = target.get(ids_name)  # type: ignore
+
+        # Do not rebase to target if the target is empty
+        if not target_ids:
+            info('target %s:%s contains no data, skipping', target, ids_name)
+            continue
+
         target_data = target_ids.to_xarray(variables=ids_vars,
                                            empty_var_ok=True)
         target_data = squash_placeholders(target_data)
@@ -67,7 +78,6 @@ def merge_data(
         ]
 
         ids_data = rebase_all_coords(ids_data, target_data)
-
         ids_data = xr.concat(ids_data, 'handle')
 
         # Now we have to get the stddeviations
@@ -76,9 +86,10 @@ def merge_data(
 
         # Then, write it back to target
         for name in ids_data.data_vars.keys():
-            target_ids.write_array_in_parts(variable_dict[name].path,
-                                            mean_data[name])
-            target_ids.write_array_in_parts(
-                variable_dict[name].path + '_error_upper', std_data[name])
+            path = variable_dict[name].path
+            target_ids.write_array_in_parts(path, mean_data[name])
+
+            path_upper = path + '_error_upper'
+            target_ids.write_array_in_parts(path_upper, std_data[name])
 
         target_ids.sync(target)
