@@ -1,20 +1,24 @@
 import logging
 import shutil
+import sys
 from pathlib import Path
 
-from importlib_resources import files
-
 from .operations import op_queue
 
+if sys.version_info < (3, 10):
+    from importlib_resources import files
+else:
+    from importlib.resources import files
+
 logger = logging.getLogger(__name__)
 
 
-def init(*, config: str, force: bool, **kwargs):
+def init(*, out_file: str, force: bool, **kwargs):
     """Initialize a brand new config file with all the default values.
 
     Parameters
     ----------
-    config : str
+    out : str
         Filename of the config.
     force : bool
         Overwrite config if it already exists.
@@ -28,7 +32,7 @@ def init(*, config: str, force: bool, **kwargs):
     """
     src = files('duqtools.data') / 'duqtools.yaml'
 
-    config_filepath = Path(config)
+    config_filepath = Path(out_file)
 
     if config_filepath.exists() and not force:
         raise RuntimeError(
