@@ -1,10 +1,6 @@
 from ._job import Job, JobStatus
 from ._locations import Locations
+from ._run import Run, Runs
 from ._system import AbstractSystem
 
-__all__ = [
-    'Locations',
-    'AbstractSystem',
-    'Job',
-    'JobStatus',
-]
+__all__ = ['Locations', 'AbstractSystem', 'Job', 'JobStatus', 'Run', 'Runs']
